==> duplex_tools-0.2.14.tar.gz: duplex_tools-0.2.14/setup.py <==
import os
import sys
import shutil
import re
import shutil
import platform
from glob import glob
from setuptools import setup, find_packages, Extension
from setuptools import Distribution, Command
from setuptools.command.install import install
import pkg_resources


__pkg_name__ = 'duplex_tools'
__dist_name__ = 'duplex_tools'
__author__ = 'ont-research'
__description__ = 'Range of tools to support operations on Duplex Sequencing read pairs.'

# Use readme as long description and say its github-flavour markdown
from os import path
this_directory = path.abspath(path.dirname(__file__))
kwargs = {'encoding':'utf-8'} if sys.version_info.major == 3 else {}
with open(path.join(this_directory, 'README.md'), **kwargs) as f:
    __long_description__ = f.read()
__long_description_content_type__ = 'text/markdown'

__path__ = os.path.dirname(__file__)
__pkg_path__ = os.path.join(os.path.join(__path__, __pkg_name__))

# find version
verstrline = open(os.path.join(__pkg_name__, '__init__.py'), 'r').read()
vsre = r"^__version__ = ['\"]([^'\"]*)['\"]"
mo = re.search(vsre, verstrline, re.M)
if mo:
    __version__ = mo.group(1)
else:
    raise RuntimeError('Unable to find version string in "{}/__init__.py".'.format(__pkg_name__))

# create requirements from requirements.txt
dir_path = os.path.dirname(__file__)
with open(os.path.join(dir_path, 'requirements.txt')) as fh:
    install_requires = [
        str(requirement) for requirement in
        pkg_resources.parse_requirements(fh)]

setup(
    name=__pkg_name__,
    version=__version__,
    url='https://github.com/nanoporetech/{}'.format(__pkg_name__),
    author=__author__,
    author_email='{}@nanoporetech.com'.format(__author__),
    description=__description__,
    long_description=__long_description__,
    long_description_content_type=__long_description_content_type__,
    install_requires=install_requires,
    tests_require=[].extend(install_requires),
    # don't include any testing subpackages in dist
    packages=find_packages(exclude=['*.test', '*.test.*', 'test.*', 'test']),
    package_data={'read_fillet':
                      ['tests/data/fastq_200-th-200/200bases-tailhead-200bases.fastq',
                       'tests/data/fastq_200-th-200-fh-200/200bases-tailhead-200bases-tailhead-200bases.fastq']},
    zip_safe=True,
    entry_points={
        'console_scripts': [
            '{0} = {0}:main'.format(__pkg_name__),
        ]
    },
)

==> duplex_tools-0.3.0.tar.gz: duplex_tools-0.3.0/setup.py <==
import os
import sys

import re

from setuptools import setup, find_packages
import pkg_resources


__pkg_name__ = 'duplex_tools'
__dist_name__ = 'duplex_tools'
__author__ = 'ont-research'
__description__ = 'Range of tools to support operations on Duplex Sequencing read pairs.'

# Use readme as long description and say its github-flavour markdown
from os import path
this_directory = path.abspath(path.dirname(__file__))
kwargs = {'encoding':'utf-8'} if sys.version_info.major == 3 else {}
with open(path.join(this_directory, 'README.md'), **kwargs) as f:
    __long_description__ = f.read()
__long_description_content_type__ = 'text/markdown'

__path__ = os.path.dirname(__file__)
__pkg_path__ = os.path.join(os.path.join(__path__, __pkg_name__))

# find version
verstrline = open(os.path.join(__pkg_name__, '__init__.py'), 'r').read()
vsre = r"^__version__ = ['\"]([^'\"]*)['\"]"
mo = re.search(vsre, verstrline, re.M)
if mo:
    __version__ = mo.group(1)
else:
    raise RuntimeError('Unable to find version string in "{}/__init__.py".'.format(__pkg_name__))

# create requirements from requirements.txt
dir_path = os.path.dirname(__file__)
with open(os.path.join(dir_path, 'requirements.txt')) as fh:
    install_requires = [
        str(requirement) for requirement in
        pkg_resources.parse_requirements(fh)]

setup(
    name=__pkg_name__,
    version=__version__,
    url='https://github.com/nanoporetech/{}'.format(__pkg_name__.replace('_', '-')),
    author=__author__,
    author_email='{}@nanoporetech.com'.format(__author__),
    description=__description__,
    long_description=__long_description__,
    long_description_content_type=__long_description_content_type__,
    install_requires=install_requires,
    tests_require=[].extend(install_requires),
    # don't include any testing subpackages in dist
    packages=find_packages(exclude=['*.test', '*.test.*', 'test.*', 'test']),
    package_data={'read_fillet':
                      ['tests/data/fastq_200-th-200/200bases-tailhead-200bases.fastq',
                       'tests/data/fastq_200-th-200-fh-200/200bases-tailhead'
                       '-200bases-tailhead-200bases.fastq'],
                  'duplex_tools':
                      ['tests/data/summaries_for_pairing/dorado_mapped.bam',
                       'tests/data/summaries_for_pairing/dorado_unmapped.bam',
                       'tests/data/summaries_for_pairing/dorado_unmapped.bam.bai',
                       'tests/data/summaries_for_pairing/seqsummary.txt',
                       
                       ]},
    zip_safe=True,
    entry_points={
        'console_scripts': [
            '{0} = {0}:main'.format(__pkg_name__),
        ]
    },
)
